==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/all_76.js <==
var searchData=
[
  ['v',['v',['../structistack.html#aa16f1de69ad69cef22523e46b69976ab',1,'istack']]],
  ['valid',['valid',['../struct__state.html#a2e5f4c9cc7b0ff82ba23766dac58204d',1,'_state']]],
  ['value',['value',['../structDrvOptCmd.html#a45e27167abb7d52c9f22d06a144400e8',1,'DrvOptCmd::value()'],['../plctrl_8c.html#a7bf0437ef5ccd8c30cdf15ac869cf3a2',1,'value():&#160;plctrl.c']]],
  ['var',['var',['../structplplot_1_1__N1.html#aa2903ee8ff4439e41d8aba6a5c477a33',1,'plplot::_N1::var()'],['../structPLOptionTable.html#a32667c6db2c9c085b99dbe120752ab32',1,'PLOptionTable::var()']]],
  ['var_5fptr',['var_ptr',['../structDrvOpt.html#ab48b331f2fc06df0473f3c3ef8ba0c5e',1,'DrvOpt']]],
  ['variable',['variable',['../namespacePlframe.html#aa53a94bcb2dc7836b90dee11786bf642',1,'Plframe']]],
  ['vars',['vars',['../structswig__varlinkobject.html#a8cf96d999cdf0b28a0e90ccb6804c9bd',1,'swig_varlinkobject']]],
  ['vasp',['vasp',['../classplstream.html#a18f26cc66fed4937f5bfc6267672b4f3',1,'plstream::vasp()'],['../classplplot_1_1core_1_1PLStream.html#a5ed6e62e306206e5f28e0f7162363409',1,'plplot.core.PLStream.vasp()']]],
  ['vdpmm',['VDPMM',['../plplotP_8h.html#a62f0b85768cd2a99c9292043f9399f0f',1,'plplotP.h']]],
  ['vect',['vect',['../classplstream.html#ad7446f51202251dc368b1f95ea523953',1,'plstream::vect()'],['../classplplot_1_1core_1_1PLStream.html#a95ec3d6f1d48da493e901aae87b423e7',1,'plplot.core.PLStream.vect()']]],
  ['verbose',['verbose',['../structPLStream.html#a2218011a15ee0bdcd5fdd5163d25d954',1,'PLStream']]],
  ['vertices',['vertices',['../structtriangle.html#a7bf0a0839ddf5997308f85b028801f25',1,'triangle::vertices()'],['../structnn__weights.html#aa342a7ebce970a8cfc3e4f752d23b607',1,'nn_weights::vertices()'],['../structnnpi.html#a7a90b61915c9b408b76a105b2786f1cd',1,'nnpi::vertices()']]],
  ['vids',['vids',['../structtriangle.html#a60d5a93bca4b2fb019932aead96fa1f6',1,'triangle']]],
  ['view',['View',['../plframe_8c.html#a63cd53b05f37ca556816e7fe45721045',1,'View(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a7cdb981597d8cc2c29f30a049d299601',1,'View(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#ab630aedd2871d69ff065e49f333a9558',1,'View(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#ac1ed87d8e29f645066818bce8282c025',1,'View(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['view_5fscroll',['view_scroll',['../namespacePlframe.html#a1392ae058c72fdd5c1551e16f20a1151',1,'Plframe']]],
  ['view_5fzoom',['view_zoom',['../namespacePlframe.html#a15fb9c0fa31c2607e6ae0a5f44571b13',1,'Plframe']]],
  ['virtual_5fpixels_5fper_5fin',['VIRTUAL_PIXELS_PER_IN',['../wxwidgets_8h.html#ae585952b2d5efb82ea2b338a07904c74',1,'VIRTUAL_PIXELS_PER_IN():&#160;wxwidgets.h'],['../gcw_8h.html#ae585952b2d5efb82ea2b338a07904c74',1,'VIRTUAL_PIXELS_PER_IN():&#160;gcw.h']]],
  ['virtual_5fpixels_5fper_5fmm',['VIRTUAL_PIXELS_PER_MM',['../wxwidgets_8h.html#ae4197bf633b93ea9a2b59258b5b1be6a',1,'VIRTUAL_PIXELS_PER_MM():&#160;wxwidgets.h'],['../gcw_8h.html#ae4197bf633b93ea9a2b59258b5b1be6a',1,'VIRTUAL_PIXELS_PER_MM():&#160;gcw.h']]],
  ['visual',['visual',['../structTkwDisplay.html#a5a5fb1c781cc45c9055ac65f98b97b37',1,'TkwDisplay::visual()'],['../structXwDisplay.html#a0a424f8e4ea00519c492925867e49e3a',1,'XwDisplay::visual()']]],
  ['void',['void',['../scstubs_8c.html#a41b01a1703b5df53c70ef8488b5749ab',1,'scstubs.c']]],
  ['vpas',['vpas',['../classplstream.html#a99cca3086170b0961ced3f6f64fa3166',1,'plstream::vpas()'],['../classplplot_1_1core_1_1PLStream.html#a0343ded0612eceaede5fcb5f8635be40',1,'plplot.core.PLStream.vpas()']]],
  ['vpdxma',['vpdxma',['../structPLStream.html#a70f57c71ace3618b3d393496450096f3',1,'PLStream']]],
  ['vpdxmi',['vpdxmi',['../structPLStream.html#a8d7fc700a977b22e669939c96dcb24fc',1,'PLStream']]],
  ['vpdyma',['vpdyma',['../structPLStream.html#acf6d7c8a591d67fcdef0dd07e00c6cf3',1,'PLStream']]],
  ['vpdymi',['vpdymi',['../structPLStream.html#a6d63bdc61fc7bf5f3328e31df9cff1d2',1,'PLStream']]],
  ['vpor',['vpor',['../classplstream.html#a558a4a11d26d066c740d69c5acdd1725',1,'plstream::vpor()'],['../classplplot_1_1core_1_1PLStream.html#a68f6f3430b9e23cadf32be4ee987dfc9',1,'plplot.core.PLStream.vpor()']]],
  ['vppxma',['vppxma',['../structPLStream.html#aa6c4b778304c44688e3bfee6b24ece84',1,'PLStream']]],
  ['vppxmi',['vppxmi',['../structPLStream.html#ae2b822caa7597bbf6158104568d4ff14',1,'PLStream']]],
  ['vppyma',['vppyma',['../structPLStream.html#a20e110cfacd22bf3f85bb0d1ba81e324',1,'PLStream']]],
  ['vppymi',['vppymi',['../structPLStream.html#a3be05ca8e59d93438f257e19eb2cbd68',1,'PLStream']]],
  ['vpwxma',['vpwxma',['../structPLStream.html#a0c3a6a8d591229bf49231b4a6c127730',1,'PLStream']]],
  ['vpwxmi',['vpwxmi',['../structPLStream.html#aa327cbb591b00e5f6be66c40e7eabea4',1,'PLStream']]],
  ['vpwyma',['vpwyma',['../structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23',1,'PLStream']]],
  ['vpwymi',['vpwymi',['../structPLStream.html#a2bbfa128180249ba951262bc3bd7ab1e',1,'PLStream']]],
  ['vscale',['VSCALE',['../wxwidgets_8h.html#ac51ccb923f4c4f470f00c1f9aa6e2c2b',1,'VSCALE():&#160;wxwidgets.h'],['../gcw_8h.html#ac51ccb923f4c4f470f00c1f9aa6e2c2b',1,'VSCALE():&#160;gcw.h']]],
  ['vsta',['vsta',['../classplstream.html#ae87e48cffe8609c379000f9876f1abba',1,'plstream::vsta()'],['../classplplot_1_1core_1_1PLStream.html#a94b0cf12968032aedb1419a4c274f5c0',1,'plplot.core.PLStream.vsta()']]],
  ['vtmp',['vtmp',['../plot3d_8c.html#a9ab85a15b7c7257de71ca5225299162b',1,'plot3d.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/all_76.js <==
var searchData=
[
  ['v',['v',['../structistack.html#aa16f1de69ad69cef22523e46b69976ab',1,'istack']]],
  ['valid',['valid',['../struct__state.html#a2e5f4c9cc7b0ff82ba23766dac58204d',1,'_state']]],
  ['value',['value',['../structDrvOptCmd.html#a45e27167abb7d52c9f22d06a144400e8',1,'DrvOptCmd::value()'],['../plctrl_8c.html#a7bf0437ef5ccd8c30cdf15ac869cf3a2',1,'value():&#160;plctrl.c']]],
  ['var',['var',['../structplplot_1_1__N1.html#aa2903ee8ff4439e41d8aba6a5c477a33',1,'plplot::_N1::var()'],['../structPLOptionTable.html#a023fced070b6f764fd16ff2c373d7eca',1,'PLOptionTable::var()']]],
  ['var_5fptr',['var_ptr',['../structDrvOpt.html#ab48b331f2fc06df0473f3c3ef8ba0c5e',1,'DrvOpt']]],
  ['variable',['variable',['../namespacePlframe.html#aa53a94bcb2dc7836b90dee11786bf642',1,'Plframe']]],
  ['vars',['vars',['../structswig__varlinkobject.html#a8cf96d999cdf0b28a0e90ccb6804c9bd',1,'swig_varlinkobject']]],
  ['vasp',['vasp',['../classplstream.html#a18f26cc66fed4937f5bfc6267672b4f3',1,'plstream::vasp()'],['../classplplot_1_1core_1_1PLStream.html#a5ed6e62e306206e5f28e0f7162363409',1,'plplot.core.PLStream.vasp()']]],
  ['vdpmm',['VDPMM',['../plplotP_8h.html#a62f0b85768cd2a99c9292043f9399f0f',1,'plplotP.h']]],
  ['vect',['vect',['../classplstream.html#ad7446f51202251dc368b1f95ea523953',1,'plstream::vect()'],['../classplplot_1_1core_1_1PLStream.html#a95ec3d6f1d48da493e901aae87b423e7',1,'plplot.core.PLStream.vect()']]],
  ['verbose',['verbose',['../structPLStream.html#a2218011a15ee0bdcd5fdd5163d25d954',1,'PLStream']]],
  ['version',['version',['../structPLmDev.html#a8263ce61819daf74e22aaf4df9e85938',1,'PLmDev']]],
  ['vertices',['vertices',['../structtriangle.html#a7bf0a0839ddf5997308f85b028801f25',1,'triangle::vertices()'],['../structnn__weights.html#aa342a7ebce970a8cfc3e4f752d23b607',1,'nn_weights::vertices()'],['../structnnpi.html#a7a90b61915c9b408b76a105b2786f1cd',1,'nnpi::vertices()']]],
  ['vids',['vids',['../structtriangle.html#a60d5a93bca4b2fb019932aead96fa1f6',1,'triangle']]],
  ['view',['View',['../plframe_8c.html#a63cd53b05f37ca556816e7fe45721045',1,'View(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a7cdb981597d8cc2c29f30a049d299601',1,'View(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#ab630aedd2871d69ff065e49f333a9558',1,'View(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#ac1ed87d8e29f645066818bce8282c025',1,'View(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['view_5fscroll',['view_scroll',['../namespacePlframe.html#a1392ae058c72fdd5c1551e16f20a1151',1,'Plframe']]],
  ['view_5fzoom',['view_zoom',['../namespacePlframe.html#a15fb9c0fa31c2607e6ae0a5f44571b13',1,'Plframe']]],
  ['vieweropenflag',['viewerOpenFlag',['../structMemoryMapHeader.html#af13b6442fe320dad8f30fd21f731671b',1,'MemoryMapHeader']]],
  ['visual',['visual',['../structTkwDisplay.html#a5a5fb1c781cc45c9055ac65f98b97b37',1,'TkwDisplay::visual()'],['../structXwDisplay.html#a0a424f8e4ea00519c492925867e49e3a',1,'XwDisplay::visual()']]],
  ['void',['void',['../scstubs_8c.html#a41b01a1703b5df53c70ef8488b5749ab',1,'scstubs.c']]],
  ['vpas',['vpas',['../classplstream.html#a99cca3086170b0961ced3f6f64fa3166',1,'plstream::vpas()'],['../classplplot_1_1core_1_1PLStream.html#a0343ded0612eceaede5fcb5f8635be40',1,'plplot.core.PLStream.vpas()']]],
  ['vpdxma',['vpdxma',['../structPLStream.html#a70f57c71ace3618b3d393496450096f3',1,'PLStream']]],
  ['vpdxmi',['vpdxmi',['../structPLStream.html#a8d7fc700a977b22e669939c96dcb24fc',1,'PLStream']]],
  ['vpdyma',['vpdyma',['../structPLStream.html#acf6d7c8a591d67fcdef0dd07e00c6cf3',1,'PLStream']]],
  ['vpdymi',['vpdymi',['../structPLStream.html#a6d63bdc61fc7bf5f3328e31df9cff1d2',1,'PLStream']]],
  ['vpor',['vpor',['../classplstream.html#a558a4a11d26d066c740d69c5acdd1725',1,'plstream::vpor()'],['../classplplot_1_1core_1_1PLStream.html#a68f6f3430b9e23cadf32be4ee987dfc9',1,'plplot.core.PLStream.vpor()']]],
  ['vppxma',['vppxma',['../structPLStream.html#aa6c4b778304c44688e3bfee6b24ece84',1,'PLStream']]],
  ['vppxmi',['vppxmi',['../structPLStream.html#ae2b822caa7597bbf6158104568d4ff14',1,'PLStream']]],
  ['vppyma',['vppyma',['../structPLStream.html#a20e110cfacd22bf3f85bb0d1ba81e324',1,'PLStream']]],
  ['vppymi',['vppymi',['../structPLStream.html#a3be05ca8e59d93438f257e19eb2cbd68',1,'PLStream']]],
  ['vpwxma',['vpwxma',['../structPLStream.html#a0c3a6a8d591229bf49231b4a6c127730',1,'PLStream']]],
  ['vpwxmi',['vpwxmi',['../structPLStream.html#aa327cbb591b00e5f6be66c40e7eabea4',1,'PLStream']]],
  ['vpwyma',['vpwyma',['../structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23',1,'PLStream']]],
  ['vpwymi',['vpwymi',['../structPLStream.html#a2bbfa128180249ba951262bc3bd7ab1e',1,'PLStream']]],
  ['vsta',['vsta',['../classplstream.html#ae87e48cffe8609c379000f9876f1abba',1,'plstream::vsta()'],['../classplplot_1_1core_1_1PLStream.html#a94b0cf12968032aedb1419a4c274f5c0',1,'plplot.core.PLStream.vsta()']]],
  ['vtmp',['vtmp',['../plot3d_8c.html#a9ab85a15b7c7257de71ca5225299162b',1,'plot3d.c']]]
];
